package WebGUI::i18n::Spanish::Shop;
use utf8;
our $I18N = {
  'Add new address' => {
    'lastUpdated' => '1276809145',
    'message' => 'Agregar dirección'
  },
  'Backordered' => {
    'lastUpdated' => '1253917361',
    'message' => 'Pendientes'
  },
  'Billing Address' => {
    'lastUpdated' => '1276809154',
    'message' => 'Dirección de Cobro'
  },
  'Cancelled' => {
    'lastUpdated' => '1215809342',
    'message' => 'Cancelado'
  },
  'Choose a payment gateway and update the cart to checkout' => {
    'lastUpdated' => '1276809179',
    'message' => 'Seleccionar un método de pago y actualizar el Carrito para completar la compra'
  },
  'Choose a payment method' => {
    'lastUpdated' => '1276809192',
    'message' => 'Seleccione el método de pago.'
  },
  'Choose a shipping method' => {
    'lastUpdated' => '1255726232',
    'message' => 'Seleccione el método de envío'
  },
  'Choose a shipping method and update the cart to checkout' => {
    'lastUpdated' => '1255726253',
    'message' => 'Seleccione el método de envío y actualize el Carrito para completar la compra'
  },
  'Failed' => {
    'lastUpdated' => '1257425077',
    'message' => 'Falló'
  },
  'No shippers' => {
    'lastUpdated' => '1253917394',
    'message' => 'No hay ningún controlador para Envíos configurado. Los usuarios no van a poder culminar ninguna compra hasta que haya configurado alguno.'
  },
  'No shipping plugins configured' => {
    'lastUpdated' => '1253917580',
    'message' => 'No hay ningún mecanismo de Envío configurado. Notifique al administrador del sitio.'
  },
  'NotShipped' => {
    'lastUpdated' => '1221669462',
    'message' => '<div id="result_box" dir="ltr">No Enviada</div>'
  },
  'Payment Information' => {
    'lastUpdated' => '1221672470',
    'message' => 'Informaci&oacute;n sobre el pago'
  },
  'Preferred Payment Type' => {
    'lastUpdated' => '1221672514',
    'message' => 'Preferencia Tipo de Pago'
  },
  'Shipped' => {
    'lastUpdated' => '1221672533',
    'message' => 'Enviado'
  },
  'Shipping Address' => {
    'lastUpdated' => '1276809201',
    'message' => 'Dirección de Envío'
  },
  'Special shipping' => {
    'lastUpdated' => '1276809210',
    'message' => 'Envío Especial'
  },
  'Status' => {
    'lastUpdated' => '1257425060',
    'message' => 'Estado'
  },
  'Success' => {
    'lastUpdated' => '1257425068',
    'message' => 'Exitoso'
  },
  'Update %s' => {
    'lastUpdated' => '1276809223',
    'message' => 'Actualizar dirección: %s'
  },
  'add a new address' => {
    'lastUpdated' => '1215809416',
    'message' => 'Adicionar una nueva direcci&oacute;n'
  },
  'add a vendor' => {
    'lastUpdated' => '1215809427',
    'message' => 'Adicionar un vendedor'
  },
  'add credit message' => {
    'lastUpdated' => '1221672606',
    'message' => '%s ha sido adicionado a %s en la cuenta de cr&eacute;dito de la tienda, para un cr&eacute;dito total de %s.'
  },
  'add payment method' => {
    'lastUpdated' => '1215810201',
    'message' => 'Adicionar un m&eacute;todo de pago'
  },
  'add shipper' => {
    'lastUpdated' => '1221672720',
    'message' => 'Adicionar M&eacute;todo de Env&iacute;o'
  },
  'add to cart' => {
    'lastUpdated' => '1215810351',
    'message' => 'Adicionar al carrito'
  },
  'addButton help' => {
    'lastUpdated' => '1215810432',
    'message' => 'Un bot&oacute;n que permitir&aacute; a los usuarios adicionar una nueva direcci&oacute;n.'
  },
  'address' => {
    'lastUpdated' => '1215725979',
    'message' => 'Direcci&oacute;n'
  },
  'address book template' => {
    'lastUpdated' => '1215810503',
    'message' => 'Plantilla Libro de Direcciones'
  },
  'address book template help' => {
    'lastUpdated' => '1221672754',
    'message' => 'Esta plantilla determina como se ver&aacute; el libro de direcciones.'
  },
  'address help' => {
    'lastUpdated' => '1215810813',
    'message' => 'Una direcci&oacute;n con formato HTML.'
  },
  'address labelField help' => {
    'lastUpdated' => '1215811851',
    'message' => 'Un campo que contiene la direcci&oacute;n etiquetada como \'residencia\' o \'trabajo\'.'
  },
  'address loop help' => {
    'lastUpdated' => '1215811909',
    'message' => 'Un bucle que contiene la lista de direcciones en este libro y sus herramientas de administraci&oacute;n.'
  },
  'address nameField help' => {
    'lastUpdated' => '1215812061',
    'message' => 'Un campo que contiene el nombre de la pesona/compa&ntilde;&iacute;a para esta direcci&oacute;n.'
  },
  'address1 help' => {
    'lastUpdated' => '1215812081',
    'message' => 'La primera l&iacute;nea de direcci&oacute;n.'
  },
  'address1Field help' => {
    'lastUpdated' => '1215812166',
    'message' => 'El campo principal de la l&iacute;nea de direcci&oacute;n.'
  },
  'address2 help' => {
    'lastUpdated' => '1215812221',
    'message' => 'La segunda l&iacute;nea de direcci&oacute;n.'
  },
  'address2Field help' => {
    'lastUpdated' => '1215812269',
    'message' => 'El campo secundario de la l&iacute;nea de direcci&oacute;n.'
  },
  'address3 help' => {
    'lastUpdated' => '1215812289',
    'message' => 'La tercera linea de direcci&oacute;n'
  },
  'address3Field help' => {
    'lastUpdated' => '1215812321',
    'message' => 'El campo terciario de la linea de direcci&oacute;n.'
  },
  'addresses loop help' => {
    'lastUpdated' => '1215812402',
    'message' => 'Un bucle que contiene todas las direcciones en esta libreta de direcciones'
  },
  'amount' => {
    'lastUpdated' => '1215812446',
    'message' => 'Cantidad'
  },
  'amount help' => {
    'lastUpdated' => '1215812511',
    'message' => 'La cantidad total de esta transacci&oacute;n, formateada con dos decimales.'
  },
  'available' => {
    'lastUpdated' => '1215812523',
    'message' => 'Disponible'
  },
  'billing address1' => {
    'lastUpdated' => '1276809284',
    'message' => 'Ingrese la dirección de cobro'
  },
  'billing city' => {
    'lastUpdated' => '1276809299',
    'message' => 'Ingrese la ciudad para la dirección de cobro.'
  },
  'billing code' => {
    'lastUpdated' => '1276809313',
    'message' => 'Ingrese el código postal para la dirección de cobro'
  },
  'billing country' => {
    'lastUpdated' => '1276809325',
    'message' => 'Ingrese el país para la dirección de cobro.'
  },
  'billing firstName' => {
    'lastUpdated' => '1276809338',
    'message' => 'Ingrese el nombre del destinatario en la dirección de cobro.'
  },
  'billing label' => {
    'lastUpdated' => '1276809351',
    'message' => 'Ingrese una etiqueta para la dirección de cobro.'
  },
  'billing lastName' => {
    'lastUpdated' => '1276809366',
    'message' => 'Ingrese el apellido del destinatario para la dirección de cobro.'
  },
  'billing phoneNumber' => {
    'lastUpdated' => '1276809396',
    'message' => 'Ingrese el número de teléfono de la dirección de cobro.'
  },
  'billing state' => {
    'lastUpdated' => '1276809407',
    'message' => 'Ingrese el estado o provincia de la dirección de cobro.'
  },
  'billingAddressChooser help' => {
    'lastUpdated' => '1280866091',
    'message' => 'Una lista de selección a partir de la cual seleccionar la dirección de cobranza por omisión.'
  },
  'biweekly' => {
    'lastUpdated' => '1215812534',
    'message' => 'Dos semanas'
  },
  'cancel recurring transaction' => {
    'lastUpdated' => '1221672788',
    'message' => 'Cancelar Transacci&oacute;n Recurrentes'
  },
  'cancelRecurringUrl' => {
    'lastUpdated' => '1221672811',
    'message' => 'Una URL que permite al usuario cancelar una transacci&oacute;n recurrente.'
  },
  'cart checkout minimum' => {
    'lastUpdated' => '1253920082',
    'message' => 'Monto mínimo de compra'
  },
  'cart checkout minimum help' => {
    'lastUpdated' => '1253920111',
    'message' => 'Indique el monto mínimo que los usuarios deben tener en el Carrito para poder completar su compra.'
  },
  'cart template' => {
    'lastUpdated' => '1221672862',
    'message' => 'Plantilla de Carrito'
  },
  'cart template help' => {
    'lastUpdated' => '1221672847',
    'message' => 'Esta plantilla determina como se ver&aacute; el carrito de compras.'
  },
  'cashier' => {
    'lastUpdated' => '1233080217',
    'message' => 'Cajero'
  },
  'checkout button' => {
    'lastUpdated' => '1221672879',
    'message' => 'Pagar'
  },
  'checkoutButton help' => {
    'lastUpdated' => '1221672927',
    'message' => 'El bot&oacute;n que el usuario pulsa para elegir un m&eacute;todo de pago.'
  },
  'choose payment gateway message' => {
    'lastUpdated' => '1221672954',
    'message' => 'C&oacute;mo te gustar&iacute;a pagar?'
  },
  'choose shipping button' => {
    'lastUpdated' => '1226520137',
    'message' => 'Elegir Direcci&oacute;n de Env&iacute;o'
  },
  'chooseShippingButton help' => {
    'lastUpdated' => '1221673059',
    'message' => 'Al hacer clic en este bot&oacute;n, se permite al usuario escoger una direcci&oacute;n de env&iacute;o de la libreta de direcciones.'
  },
  'city' => {
    'lastUpdated' => '1215812577',
    'message' => 'Ciudad'
  },
  'city help' => {
    'lastUpdated' => '1221673073',
    'message' => 'La ciudad para esta direcci&oacute;n.'
  },
  'cityField help' => {
    'lastUpdated' => '1221673090',
    'message' => 'Un campo que contiene la ciudad para esta direcci&oacute;n.'
  },
  'code' => {
    'lastUpdated' => '1221673102',
    'message' => 'C&oacute;digo Postal'
  },
  'code help' => {
    'lastUpdated' => '1221673117',
    'message' => 'El c&oacute;digo postal para esta direcci&oacute;n.'
  },
  'codeField help' => {
    'lastUpdated' => '1221673137',
    'message' => 'Un campo que contiene el c&oacute;digo postal para esta direcci&oacute;n.'
  },
  'company url' => {
    'lastUpdated' => '1221673543',
    'message' => 'URL de la Compa&ntilde;ia'
  },
  'configuredTitle' => {
    'lastUpdated' => '1221673606',
    'message' => 'El t&iacute;tulo configurado para el assetId. Este es el t&iacute;tulo regular del activo con personalizaciones del usuario.'
  },
  'configuredTitle help' => {
    'lastUpdated' => '1221673690',
    'message' => 'El nombre del item configurado para la compra.'
  },
  'continue shopping button' => {
    'lastUpdated' => '1221673704',
    'message' => 'Continuar Comprando'
  },
  'continueShoppingButton help' => {
    'lastUpdated' => '1221673745',
    'message' => 'Al hacer click en este bot&oacute;n el usuario volver&aacute; al sitio.'
  },
  'copy from home address' => {
    'lastUpdated' => '1253920161',
    'message' => 'Tomar Dirección de Habitación del Perfil'
  },
  'copy from work address' => {
    'lastUpdated' => '1253920147',
    'message' => 'Tomar Dirección de Trabajo del Perfil'
  },
  'country' => {
    'lastUpdated' => '1221673756',
    'message' => 'Pa&iacute;s'
  },
  'country help' => {
    'lastUpdated' => '1221674015',
    'message' => 'El pa&iacute;s para esta direcci&oacute;n.'
  },
  'countryField help' => {
    'lastUpdated' => '1221674035',
    'message' => 'Un campo que contiene el pa&iacute;s para esta direcci&oacute;n.'
  },
  'coupon' => {
    'lastUpdated' => '1221674064',
    'message' => 'Cup&oacute;n'
  },
  'current credit message' => {
    'lastUpdated' => '1276809422',
    'message' => '%s tiene un crédito de %s.'
  },
  'date' => {
    'lastUpdated' => '1221674077',
    'message' => 'Fecha'
  },
  'date created' => {
    'lastUpdated' => '1221674100',
    'message' => 'Fecha de Creaci&oacute;n'
  },
  'dateAdded help' => {
    'lastUpdated' => '1221674127',
    'message' => 'La fecha y hora en que este item fue adicionado al carrito.'
  },
  'dateOfPurchase' => {
    'lastUpdated' => '1221674144',
    'message' => 'La fecha en que ocurri&oacute; la compra.'
  },
  'default' => {
    'lastUpdated' => '1233080230',
    'message' => 'Poner por Defecto'
  },
  'defaultButton help' => {
    'lastUpdated' => '1233080254',
    'message' => 'Un botón que permitirá al usuario poner una dirección por defecto.'
  },
  'delete' => {
    'lastUpdated' => '1221674150',
    'message' => 'Borrar'
  },
  'deleteButton help' => {
    'lastUpdated' => '1221674209',
    'message' => 'Un bot&oacute;n que permitir&aacute; al usuario borrar una direcci&oacute;n existente.'
  },
  'deschedule all button' => {
    'lastUpdated' => '1253920181',
    'message' => 'Suspender todas'
  },
  'edit' => {
    'lastUpdated' => '1221674216',
    'message' => 'Editar'
  },
  'edit address template' => {
    'lastUpdated' => '1221674235',
    'message' => 'Plantilla Editar Direcci&oacute;n'
  },
  'edit address template help' => {
    'lastUpdated' => '1221674376',
    'message' => 'Esta plantilla determina como se ver&aacute; el editor de direcci&oacute;n.'
  },
  'editButton help' => {
    'lastUpdated' => '1221674398',
    'message' => 'Un bot&oacute;n que permitir&aacute; al usuario editar una direcci&oacute;n existente.'
  },
  'email' => {
    'lastUpdated' => '1226520087',
    'message' => 'Correo Electr&oacute;nico'
  },
  'emailField help' => {
    'lastUpdated' => '1280866117',
    'message' => 'Un campo para contener la dirección de correo electrónico asociada a esta dirección.'
  },
  'empty cart' => {
    'lastUpdated' => '1221674416',
    'message' => 'No hay items actualmente en tu carrito.'
  },
  'error help' => {
    'lastUpdated' => '1221674457',
    'message' => 'Si hay alg&uacute;n problema el mensaje de error se mostrar&aacute; aqu&iacute;.'
  },
  'export tax' => {
    'lastUpdated' => '1221674491',
    'message' => 'Impuestos de Exportaci&oacute;n'
  },
  'extended price' => {
    'lastUpdated' => '1221758376',
    'message' => 'Precio Prorrogado'
  },
  'extendedPrice help' => {
    'lastUpdated' => '1221768262',
    'message' => 'El resultado del precio multiplicado por la cantidad.'
  },
  'firstName' => {
    'lastUpdated' => '1221768147',
    'message' => 'Primer Nombre'
  },
  'formFooter help' => {
    'lastUpdated' => '1221768204',
    'message' => '<div id="result_box" dir="ltr">La parte inferior del formulario.</div>'
  },
  'formHeader help' => {
    'lastUpdated' => '1221768220',
    'message' => 'La prte de arriba del formulario.'
  },
  'fourweekly' => {
    'lastUpdated' => '1221768231',
    'message' => 'Cuatro semanas'
  },
  'group label' => {
    'lastUpdated' => '1253920193',
    'message' => 'Etiqueta'
  },
  'group rate' => {
    'lastUpdated' => '1253920202',
    'message' => 'Tasa de Impuesto'
  },
  'halfyearly' => {
    'lastUpdated' => '1221768244',
    'message' => 'Medio A&ntilde;o'
  },
  'hasShippingAddress help' => {
    'lastUpdated' => '1221854298',
    'message' => '<div id="result_box" dir="ltr">Una condici&oacute;n que indica si el usuario ya ha especificado una direcci&oacute;n de env&iacute;o. Direcci&oacute;n de env&iacute;o es siempre necesaria con el fin de calcular los impuestos.</div>'
  },
  'hasSku' => {
    'lastUpdated' => '1307399381',
    'message' => 'Un condicional que indica si el Activo al cual hace referencia este item aún existe en WebGUI o no. Si no existe, no debe intentarse el acceso a viewItemUrl.'
  },
  'import tax' => {
    'lastUpdated' => '1221854316',
    'message' => 'Impuestos de Importaci&oacute;n'
  },
  'in shop credit' => {
    'lastUpdated' => '1221854392',
    'message' => 'Cr&eacute;dito en la Tienda'
  },
  'in shop credit used' => {
    'lastUpdated' => '1221854438',
    'message' => 'Cr&eacute;dito Usado en la Tienda'
  },
  'inShopCreditAvailable help' => {
    'lastUpdated' => '1221854463',
    'message' => 'El valor del cr&eacute;dito en la tienda del usuario'
  },
  'inShopCreditDeduction help' => {
    'lastUpdated' => '1221854614',
    'message' => 'El monto del cr&eacute;dito en la tienda que ha sido aplicado a esta compra.'
  },
  'is a required field' => {
    'lastUpdated' => '1221854640',
    'message' => '%s es un campo obligatorio.'
  },
  'isCashier' => {
    'lastUpdated' => '1233080282',
    'message' => 'Un booleano el cual será verdadero si el usuario actual puede ser un cajero dentro de la Tienda.'
  },
  'isRecurring' => {
    'lastUpdated' => '1222098487',
    'message' => 'Un boleano que es verdad si &eacute;sta es una transacci&oacute;n recurrente.'
  },
  'isShippable help' => {
    'lastUpdated' => '1222105337',
    'message' => 'A condici&oacute;n que indique si el item puede tener una direcci&oacute;n de env&iacute;o adjuntada.'
  },
  'isSuccessful' => {
    'lastUpdated' => '1222105366',
    'message' => 'S&iacute; o no esta transacci&oacute;n se ha completado correctamente.'
  },
  'isUnique help' => {
    'lastUpdated' => '1222105399',
    'message' => '<div id="result_box" dir="ltr">A condici&oacute;n que indique si este item es &uacute;nico y, por tanto, s&oacute;lo puede tener la cantidad de 1.</div>'
  },
  'item' => {
    'lastUpdated' => '1221857967',
    'message' => 'Item'
  },
  'item assetId' => {
    'lastUpdated' => '1222105414',
    'message' => 'El assetId para este item.'
  },
  'item extendedPricePlusTax help' => {
    'lastUpdated' => '1280866178',
    'message' => 'La el precio del item más el impuesto, multiplicado por la cantidad de items como este en el carrito. Esta variable solamente tendrá valor cuando el usuario actual no es el Invitado.'
  },
  'item lastUpdated' => {
    'lastUpdated' => '1222105678',
    'message' => 'La fecha en que se actualiz&oacute; por &uacute;ltima vez la transacci&oacute;n de este item.'
  },
  'item name help' => {
    'lastUpdated' => '1222105696',
    'message' => 'El nombre o t&iacute;tulo del producto.'
  },
  'item options' => {
    'lastUpdated' => '1222105759',
    'message' => 'opciones JSON codificados para el activo. Probablemente no deber&iacute;a utilizar esta variable de plantilla.'
  },
  'item price' => {
    'lastUpdated' => '1222105835',
    'message' => 'El precio sin formatear de este SKU.'
  },
  'item pricePlusTax help' => {
    'lastUpdated' => '1280866223',
    'message' => 'El precio del item más el monto del impuesto. Esta variable tendrá valor solamente cuando el usuario actual no sea el usuario Invitado.'
  },
  'item quantity' => {
    'lastUpdated' => '1222105856',
    'message' => 'La cantidad del SKU que fue comprado.'
  },
  'item shipToButton help' => {
    'lastUpdated' => '1222109824',
    'message' => 'Al hacer clic en este bot&oacute;n establecer&aacute; una direcci&oacute;n alternativa como destino de este item.'
  },
  'item shippingAddress1' => {
    'lastUpdated' => '1222456006',
    'message' => 'Esta es la primera l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o para este item.'
  },
  'item shippingAddress2' => {
    'lastUpdated' => '1222111030',
    'message' => 'Esta es la segunda l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o para este item.'
  },
  'item shippingAddress3' => {
    'lastUpdated' => '1222111037',
    'message' => 'Esta es la tercera l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o para este item.'
  },
  'item shippingAddressCity' => {
    'lastUpdated' => '1222111045',
    'message' => 'La ciudad de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingAddressCode' => {
    'lastUpdated' => '1222111051',
    'message' => 'El c&oacute;digo de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingAddressCountry' => {
    'lastUpdated' => '1222111058',
    'message' => 'El pa&iacute;s de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingAddressId' => {
    'lastUpdated' => '1222111064',
    'message' => 'El ID de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingAddressPhoneNumber' => {
    'lastUpdated' => '1222111070',
    'message' => 'El n&uacute;mero telef&oacute;nico de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingAddressState' => {
    'lastUpdated' => '1222111084',
    'message' => 'El departamento de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'item shippingName' => {
    'lastUpdated' => '1222111090',
    'message' => 'El nombre asignado a la direcci&oacute;n de env&iacute;o de este item.'
  },
  'item sku deleted' => {
    'lastUpdated' => '1307399400',
    'message' => 'El Activo asociado a este item no puede ser instanciado.'
  },
  'item taxAmount help' => {
    'lastUpdated' => '1280866251',
    'message' => 'El monto del impuesto para este item. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
  },
  'item taxRate help' => {
    'lastUpdated' => '1280866276',
    'message' => 'La tasa de impuesto para este item. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
  },
  'item transactionId' => {
    'lastUpdated' => '1222110126',
    'message' => 'El ID de la transacci&oacute;n que pertenece este item.'
  },
  'item url help' => {
    'lastUpdated' => '1222110166',
    'message' => 'La url para ver como est&aacute; configurado este item.'
  },
  'item vendorId' => {
    'lastUpdated' => '1222110179',
    'message' => 'El ID del vendedor de este item.'
  },
  'itemAddressChooser help' => {
    'lastUpdated' => '1280866323',
    'message' => 'Una lista de selección de la cual escoger la dirección de envío para un item individual en el carrito, permitiendo envío separado por item.'
  },
  'itemId' => {
    'lastUpdated' => '1222110251',
    'message' => 'El identificador &uacute;nico para este item entre todos los items en todas las transacciones.'
  },
  'itemShippingAddress' => {
    'lastUpdated' => '1222111103',
    'message' => 'El formato de la direcci&oacute;n de env&iacute;o para este item.'
  },
  'items' => {
    'lastUpdated' => '1222111150',
    'message' => 'Un bucle que contiene todos los items asociados con esta transacci&oacute;n.'
  },
  'items loop help' => {
    'lastUpdated' => '1222111521',
    'message' => 'Un bucle que contiene las variables para cada item en el carrito.'
  },
  'label' => {
    'lastUpdated' => '1221857951',
    'message' => 'Etiqueta'
  },
  'label help' => {
    'lastUpdated' => '1222111550',
    'message' => 'por ejemplo: \'Casa\' o \'Trabajo\''
  },
  'lastName' => {
    'lastUpdated' => '1221857993',
    'message' => 'Apellido'
  },
  'login message' => {
    'lastUpdated' => '1222111641',
    'message' => 'Debes estar logueado para pagar. Para loguearte has click <a href="%s">aqu&iacute;</a>'
  },
  'loginFormButton help' => {
    'lastUpdated' => '1280866362',
    'message' => 'El botón para enviar el formulario de autenticación. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
  },
  'loginFormFooter help' => {
    'lastUpdated' => '1280866400',
    'message' => 'Fragmento de HTML para terminar el formulario de autenticación. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
  },
  'loginFormHeader help' => {
    'lastUpdated' => '1280866430',
    'message' => 'Fragmento de HTML para comenzar el formulario de autenticación. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
  },
  'loginFormPassword help' => {
    'lastUpdated' => '1280866484',
    'message' => 'El campo de texto en el cual el usuario introduce su clave. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
  },
  'loginFormUsername help' => {
    'lastUpdated' => '1280866516',
    'message' => 'El campo de texto en el cual el usuario introduce su nombre. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
  },
  'manage' => {
    'lastUpdated' => '1221857909',
    'message' => 'Administrar'
  },
  'manage my purchases template' => {
    'lastUpdated' => '1222111681',
    'message' => 'Plantilla Administrar mis Compras'
  },
  'manage my purchases template help' => {
    'lastUpdated' => '1222111715',
    'message' => 'Esta plantila muestra informaci&oacute;n parcial sobre las transacciones al usuario.'
  },
  'message help' => {
    'lastUpdated' => '1280866541',
    'message' => 'Si el carrito de compras está vacío, presentar este mensaje al usuario.'
  },
  'minicart template' => {
    'lastUpdated' => '1222111745',
    'message' => 'Plantilla MiniCart'
  },
  'minicart template help' => {
    'lastUpdated' => '1222111856',
    'message' => 'Las siguientes variables estan disponibles en la plantilla de la macro MiniCart.'
  },
  'minimumCartAmount help' => {
    'lastUpdated' => '1280866575',
    'message' => 'El monto mínimo en el carrito de compras según la configuración, con dos lugares decimales.'
  },
  'mixed items warning' => {
    'lastUpdated' => '1222185905',
    'message' => '<div id="result_box" dir="ltr">No es posible pagar con los items recurrentes y no recurrentes en su carrito. Puede tener ya sea un item recurrente, o como muchos items no recurrentes como desee en su carrito de compra en el tiempo. Si usted necesita comprar ambos, a continuaci&oacute;n, por favor comprarlos por transacciones separado las transacciones.</div>'
  },
  'monthly' => {
    'lastUpdated' => '1221857896',
    'message' => 'Mes'
  },
  'my purchases' => {
    'lastUpdated' => '1222186022',
    'message' => '<div id="result_box" dir="ltr">Mis compras</div>'
  },
  'my purchases detail template' => {
    'lastUpdated' => '1222186043',
    'message' => 'Plantilla Detalle Mis Compras'
  },
  'my purchases detail template help' => {
    'lastUpdated' => '1222371840',
    'message' => 'Plantilla que debe utilizarse para mostrar el historial detallado de ordenes de un usuario? Un individuo venta en lugar de toda la lista de transacciones.'
  },
  'my purchases template' => {
    'lastUpdated' => '1222374381',
    'message' => 'Plantilla Mis Compras'
  },
  'my purchases template help' => {
    'lastUpdated' => '1222455657',
    'message' => '<div id="result_box" dir="ltr">Plantilla que debe utilizarse para mostrar el historial de ordenes de un usuario?</div>'
  },
  'name' => {
    'lastUpdated' => '1221857593',
    'message' => 'Nombre'
  },
  'name help' => {
    'lastUpdated' => '1222455678',
    'message' => 'El nombre de la persona de esta direcci&oacute;n.'
  },
  'no billing address' => {
    'lastUpdated' => '1276809508',
    'message' => 'Ingrese una dirección de cobro, o indique alguna existente.'
  },
  'no shipping address' => {
    'lastUpdated' => '1276809523',
    'message' => 'Ingrese una dirección de envío, o indique alguna existente.'
  },
  'not applicable' => {
    'lastUpdated' => '1222455694',
    'message' => 'N/A'
  },
  'not scheduled payout amount' => {
    'lastUpdated' => '1253920246',
    'message' => 'No está en vía de pago'
  },
  'notes' => {
    'lastUpdated' => '1221857611',
    'message' => 'Notas sobre esta transacci&oacute;n'
  },
  'notice' => {
    'lastUpdated' => '1221857879',
    'message' => 'Cualquier mensaje desde el sistema para ser mostrado al usuario.'
  },
  'order for' => {
    'lastUpdated' => '1233080298',
    'message' => 'Orden Para'
  },
  'order number' => {
    'lastUpdated' => '1221858009',
    'message' => 'Orden #'
  },
  'order status' => {
    'lastUpdated' => '1221858222',
    'message' => 'Estado de la Orden'
  },
  'orderNumber' => {
    'lastUpdated' => '1222277370',
    'message' => '<div id="result_box" dir="ltr">Un n&uacute;mero legible por el hombre para la transacci&oacute;n.</div>'
  },
  'orderStatus' => {
    'lastUpdated' => '1222455807',
    'message' => 'El estado internacionalizado para este item, Enviado, Cancelado, Pendiente o no Enviada'
  },
  'organization' => {
    'lastUpdated' => '1226520053',
    'message' => 'Organizaci&oacute;n'
  },
  'organization help' => {
    'lastUpdated' => '1233080331',
    'message' => 'El nombre de una organización que usa esta dirección. Probablemente el lugar de tu trabajo.'
  },
  'originatingTransactionId' => {
    'lastUpdated' => '1222455905',
    'message' => 'Si la transacci&oacute;n es recurrente, contendr&aacute; el Id de la transacci&oacute;n para la compra original.'
  },
  'payment address' => {
    'lastUpdated' => '1222455991',
    'message' => 'Direcci&oacute;n de Pago'
  },
  'payment method' => {
    'lastUpdated' => '1221857842',
    'message' => 'M&eacute;todo de Pago'
  },
  'payment methods' => {
    'lastUpdated' => '1221857853',
    'message' => 'M&eacute;todos de Pago'
  },
  'paymentAddress' => {
    'lastUpdated' => '1222277123',
    'message' => 'Formato de pago/direcci&oacute;n de facturaci&oacute;n.'
  },
  'paymentAddress1' => {
    'lastUpdated' => '1222911699',
    'message' => 'La primera l&iacute;nea en una multil&iacute;nea de direcciones de pago.'
  },
  'paymentAddress2' => {
    'lastUpdated' => '1222456080',
    'message' => 'La segunda l&iacute;nea en una multil&iacute;nea de direcciones de pago.'
  },
  'paymentAddress3' => {
    'lastUpdated' => '1222456180',
    'message' => 'La tercera l&iacute;nea en una multil&iacute;nea de direcciones de pago.'
  },
  'paymentAddressCity' => {
    'lastUpdated' => '1222456225',
    'message' => 'La ciudad de la direcci&oacute;n de pago.'
  },
  'paymentAddressCode' => {
    'lastUpdated' => '1222456249',
    'message' => 'El codigo postal para la direcci&oacute;n de pago.'
  },
  'paymentAddressCountry' => {
    'lastUpdated' => '1222456396',
    'message' => 'El pa&iacute;s de la direcci&oacute;n de pago.'
  },
  'paymentAddressId' => {
    'lastUpdated' => '1222456521',
    'message' => 'El ID de la direcci&oacute;n de pago usado por esta transacci&oacute;n.'
  },
  'paymentAddressName' => {
    'lastUpdated' => '1222459424',
    'message' => 'El nombre asignado a la direcci&oacute;n de pago.'
  },
  'paymentAddressPhoneNumber' => {
    'lastUpdated' => '1222459730',
    'message' => 'El n&uacute;mero telef&oacute;nico para la direcci&oacute;n de pago.'
  },
  'paymentAddressState' => {
    'lastUpdated' => '1222459749',
    'message' => 'El departamento para la direcci&oacute;n de pago.'
  },
  'paymentOptions help' => {
    'lastUpdated' => '1280866613',
    'message' => 'Una lista de selección conteniendo todos los métodos de pago para esta orden.'
  },
  'per item shipping' => {
    'lastUpdated' => '1222459820',
    'message' => 'Por item enviado'
  },
  'phone number' => {
    'lastUpdated' => '1221857626',
    'message' => 'N&uacute;mero Telef&oacute;nico'
  },
  'phoneNumber help' => {
    'lastUpdated' => '1222469820',
    'message' => 'Un n&uacute;mero telef&oacute;nico para esta direcci&oacute;n.'
  },
  'phoneNumberField help' => {
    'lastUpdated' => '1222698059',
    'message' => 'Un campo que contiene el n&uacute;mero telef&oacute;nico para esta direcci&oacute;n.'
  },
  'posLookupForm' => {
    'lastUpdated' => '1233080494',
    'message' => 'Un formulario donde el cajero pueda buscar un usuario por correo electrónico.'
  },
  'posUserId' => {
    'lastUpdated' => '1233080464',
    'message' => 'El id del usuario para hacer la transacción POS.'
  },
  'posUsername' => {
    'lastUpdated' => '1233080445',
    'message' => 'El nombre de usuario para hacer la transacción POS.'
  },
  'price' => {
    'lastUpdated' => '1221857635',
    'message' => 'Precio'
  },
  'price help' => {
    'lastUpdated' => '1222698086',
    'message' => 'El precio de este item, formateado a dos decimales.'
  },
  'print' => {
    'lastUpdated' => '1221857643',
    'message' => 'Imprimir'
  },
  'products' => {
    'lastUpdated' => '1221858020',
    'message' => 'Productos'
  },
  'quantity' => {
    'lastUpdated' => '1221858029',
    'message' => 'Cantidad'
  },
  'quantity help' => {
    'lastUpdated' => '1222698139',
    'message' => 'La cantidad de este item que se compra.'
  },
  'quantityField help' => {
    'lastUpdated' => '1222698170',
    'message' => 'El campo donde el usuario puede especificar la cantidad del item que desea comprar.'
  },
  'quarterly' => {
    'lastUpdated' => '1222698192',
    'message' => 'Tres meses'
  },
  'receipt email template' => {
    'lastUpdated' => '1259455966',
    'message' => 'Plantilla para Confirmación por Correo'
  },
  'receipt email template help' => {
    'lastUpdated' => '1259456003',
    'message' => 'Indique la plantilla a emplear para generar el mensaje de correo que debe enviarse a los usuarios para confirmar su compra.'
  },
  'refund' => {
    'lastUpdated' => '1222698227',
    'message' => 'Reembolso'
  },
  'registerLink help' => {
    'lastUpdated' => '1280866655',
    'message' => 'El enlace para que el usuario registre una cuenta en este sitio, cuando no tengan una. Esta variable tendrá valor solamente si el usuario actual es el usuario Invitado.'
  },
  'remove button' => {
    'lastUpdated' => '1222698237',
    'message' => 'Borrar'
  },
  'removeBox help' => {
    'lastUpdated' => '1280867141',
    'message' => 'Un checkbox que permite retirar este item del carrito.'
  },
  'removeButton help' => {
    'lastUpdated' => '1222698266',
    'message' => 'Al hacer click en este bot&oacute;n borrar&aacute; ek item del carrito.'
  },
  'required minimum order amount' => {
    'lastUpdated' => '1253920258',
    'message' => 'Monto mínimo a ordenar:'
  },
  'sale notification group' => {
    'lastUpdated' => '1259455910',
    'message' => 'Grupo para Notificación de Venta'
  },
  'sale notification group help' => {
    'lastUpdated' => '1259455935',
    'message' => 'Indique el Grupo de usuarios que deben recibir notificaciones cuando ocurran transacciones.'
  },
  'sameShippingAsBilling help' => {
    'lastUpdated' => '1280867177',
    'message' => 'Un checkbox para indicar al carrito de compras que el usuario emplea la misma dirección de envío como dirección de cobranza.'
  },
  'saveButton help' => {
    'lastUpdated' => '1222979583',
    'message' => 'El bot&oacute;n por defecto para guardar el formulario.'
  },
  'schedule all button' => {
    'lastUpdated' => '1253920271',
    'message' => 'Procesar todos'
  },
  'scheduled payout amount' => {
    'lastUpdated' => '1253920283',
    'message' => 'Procesadas para pago'
  },
  'search for email' => {
    'lastUpdated' => '1233080416',
    'message' => 'Buscar por Correo Electrónico'
  },
  'select gateway template' => {
    'lastUpdated' => '1259455889',
    'message' => 'Plantilla para Selección del Método de Pago'
  },
  'select gateway template help' => {
    'lastUpdated' => '1259455873',
    'message' => 'Indique la plantilla a emplear para seleccionar el Método de Pago.'
  },
  'ship to button' => {
    'lastUpdated' => '1222911635',
    'message' => 'Enviar a'
  },
  'shipToButton help' => {
    'lastUpdated' => '1222979562',
    'message' => 'Hace lo mismo queel bot&oacute;n Elegir direcci&oacute;n de env&iacute;o'
  },
  'shippableItemsInCart' => {
    'lastUpdated' => '1276809546',
    'message' => 'Un condicional que indica si al menos un item en el carrito requiere envío.'
  },
  'shipping' => {
    'lastUpdated' => '1222911598',
    'message' => 'Envio'
  },
  'shipping address' => {
    'lastUpdated' => '1222911711',
    'message' => 'Direcci&oacute;n de Env&iacute;o'
  },
  'shipping address1' => {
    'lastUpdated' => '1276809563',
    'message' => 'Indique la dirección de envío.'
  },
  'shipping amount' => {
    'lastUpdated' => '1222979413',
    'message' => 'Valor de Env&iacute;o'
  },
  'shipping city' => {
    'lastUpdated' => '1276809579',
    'message' => 'Indique la ciudad de la dirección de envío.'
  },
  'shipping code' => {
    'lastUpdated' => '1276809621',
    'message' => 'Indique el código postal para la dirección de envío.'
  },
  'shipping country' => {
    'lastUpdated' => '1276809632',
    'message' => 'Indique el país para la dirección de envío.'
  },
  'shipping firstName' => {
    'lastUpdated' => '1276809668',
    'message' => 'Indique el nombre del destinatario en la dirección de envío.'
  },
  'shipping label' => {
    'lastUpdated' => '1276809686',
    'message' => 'Indique la etiqueta para la dirección de envío.'
  },
  'shipping lastName' => {
    'lastUpdated' => '1276809700',
    'message' => 'Indique el apellido del destinatario en la dirección de envío.'
  },
  'shipping method' => {
    'lastUpdated' => '1276809715',
    'message' => 'Método de Envío'
  },
  'shipping methods' => {
    'lastUpdated' => '1276809730',
    'message' => 'Métodos de Envío'
  },
  'shipping phoneNumber' => {
    'lastUpdated' => '1276809742',
    'message' => 'Indique el teléfono de contacto para la dirección de envío.'
  },
  'shipping state' => {
    'lastUpdated' => '1276809754',
    'message' => 'Indique el estado/provincia para la dirección de envío.'
  },
  'shippingAddress help' => {
    'lastUpdated' => '1222979464',
    'message' => 'El HTML formateado de la direcci&oacute;n a enviar.'
  },
  'shippingAddress1' => {
    'lastUpdated' => '1222911735',
    'message' => 'La primera l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o.'
  },
  'shippingAddress2' => {
    'lastUpdated' => '1222911756',
    'message' => 'La segunda l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o.'
  },
  'shippingAddress3' => {
    'lastUpdated' => '1222911779',
    'message' => 'La tercera l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o.'
  },
  'shippingAddressChooser help' => {
    'lastUpdated' => '1280866786',
    'message' => 'Una lista de selección para escoger la dirección de despacho por defecto para todos los items del carrito. También contiene acciones para editar o agregar direcciones.'
  },
  'shippingAddressCity' => {
    'lastUpdated' => '1222911793',
    'message' => 'La ciudad de la direcci&oacute;n de env&iacute;o.'
  },
  'shippingAddressCode' => {
    'lastUpdated' => '1222911813',
    'message' => 'El c&oacute;digo postal de la direcci&oacute;n de env&iacute;o.'
  },
  'shippingAddressCountry' => {
    'lastUpdated' => '1222911827',
    'message' => 'El pa&iacute;s de la direcci&oacute;n de env&iacute;o.'
  },
  'shippingAddressId' => {
    'lastUpdated' => '1222911861',
    'message' => 'El ID de la direcci&oacute;n de env&iacute;o usada para esta transacci&oacute;n.'
  },
  'shippingAddressName' => {
    'lastUpdated' => '1222911881',
    'message' => 'El nombre asignado a la direcci&oacute;n de env&iacute;o.'
  },
  'shippingAddressPhoneNumber' => {
    'lastUpdated' => '1222911914',
    'message' => 'El n&uacute;mero tel&eacute;fonico para la direcci&oacute;n de env&iacute;o.'
  },
  'shippingAddressState' => {
    'lastUpdated' => '1222911929',
    'message' => 'El departamento de la direcci&oacute;n de env&iacute;o.'
  },
  'shippingDriverId' => {
    'lastUpdated' => '1222911989',
    'message' => 'El identificador &uacute;nico para el driver de env&iacute;o usado en esta transacci&oacute;n.'
  },
  'shippingDriverLabel' => {
    'lastUpdated' => '1222912042',
    'message' => 'La etiqueta psra el driver de env&iacute;o usado en esta trasacci&oacute;n.'
  },
  'shippingOptions help' => {
    'lastUpdated' => '1222979503',
    'message' => 'Una lista de selecci&oacute;n que contiene todas las opciones configuradas de env&iacute;o para esta orden.'
  },
  'shippingPrice help' => {
    'lastUpdated' => '1222912072',
    'message' => 'Precio de env&iacute;o, formateado a dos decimales.'
  },
  'shop' => {
    'lastUpdated' => '1221857655',
    'message' => 'Tienda'
  },
  'shop notice' => {
    'lastUpdated' => '1222912134',
    'message' => 'Notificaci&oacute;n de la tienda'
  },
  'shop settings' => {
    'lastUpdated' => '1222912178',
    'message' => 'Configuraci&oacute;n de la Tienda'
  },
  'shopCreditDeduction' => {
    'lastUpdated' => '1222912249',
    'message' => 'El valor sin formatear del cr&eacute;dito de la tienda usado en esta transacci&oacute;n.'
  },
  'state' => {
    'lastUpdated' => '1215811444',
    'message' => 'Departamento'
  },
  'state help' => {
    'lastUpdated' => '1221798457',
    'message' => 'El departamento o provincia para esta direcci&oacute;n.'
  },
  'stateField help' => {
    'lastUpdated' => '1221798422',
    'message' => 'Un campo que contiene el Departamento o Provincia para esta direcci&oacute;n.'
  },
  'status code' => {
    'lastUpdated' => '1221798392',
    'message' => 'C&oacute;digo de Estado'
  },
  'status message' => {
    'lastUpdated' => '1221798378',
    'message' => 'Mensaje de Estado'
  },
  'statusCode' => {
    'lastUpdated' => '1221798367',
    'message' => 'El c&oacute;digo de estado que ven&iacute;a de la gateway de pago cuando intenta procesar el pago.'
  },
  'statusMessage' => {
    'lastUpdated' => '1221798326',
    'message' => 'El mensaje de estado extendido que ven&iacute;a desde la gateway de pago cuando intenta procesar el pago.'
  },
  'submit scheduled payouts button' => {
    'lastUpdated' => '1253920303',
    'message' => 'Procesar Pagos'
  },
  'subtotal' => {
    'lastUpdated' => '1215811373',
    'message' => 'Subtotal'
  },
  'subtotalPrice help' => {
    'lastUpdated' => '1221798199',
    'message' => 'El precio de todos los items en el carrito.'
  },
  'tax' => {
    'lastUpdated' => '1215811247',
    'message' => 'Impuesto'
  },
  'tax help' => {
    'lastUpdated' => '1221798095',
    'message' => 'El precio de los impuestos sobre todos los items en el carrito.'
  },
  'taxes' => {
    'lastUpdated' => '1215811238',
    'message' => 'Impuestos'
  },
  'taxes help' => {
    'lastUpdated' => '1221798011',
    'message' => '<div id="result_box" dir="ltr">Impuestos sobre esta transacci&oacute;n, con formato a dos decimales.</div>'
  },
  'thank you message' => {
    'lastUpdated' => '1215811709',
    'message' => 'Gracias por su pedido! Por favor, guarde esto como su recibo.'
  },
  'too many of this item' => {
    'lastUpdated' => '1221797957',
    'message' => 'No puedes adicionar m&aacute;s %s a tu carrito.'
  },
  'total' => {
    'lastUpdated' => '1215811107',
    'message' => 'Total'
  },
  'totalItems help' => {
    'lastUpdated' => '1215811742',
    'message' => 'El n&uacute;mero total de items en el carrito.'
  },
  'totalPrice help' => {
    'lastUpdated' => '1221797923',
    'message' => 'El precio total de compra del carrito, tal como est&aacute; actualmente.'
  },
  'tracking number' => {
    'lastUpdated' => '1221797854',
    'message' => '# Seguimiento'
  },
  'transaction id' => {
    'lastUpdated' => '1221797544',
    'message' => 'ID de Transacci&oacute;n'
  },
  'transactionCode' => {
    'lastUpdated' => '1221798177',
    'message' => 'C&oacute;digo de transacci&oacute;n o ID&nbsp; otorgado por la gateway de pago. No todas las gateway pueden soportar esto.'
  },
  'transactionId' => {
    'lastUpdated' => '1221796584',
    'message' => 'El identificador &uacute;nico para esta transacci&oacute;n.'
  },
  'transactions' => {
    'lastUpdated' => '1215811061',
    'message' => 'Transacciones'
  },
  'update' => {
    'lastUpdated' => '1215811087',
    'message' => 'Actualizar'
  },
  'update cart button' => {
    'lastUpdated' => '1221796556',
    'message' => 'Actualizar Carrito'
  },
  'updateButton help' => {
    'lastUpdated' => '1221788819',
    'message' => '<div id="result_box" dir="ltr">Al hacer clic en este bot&oacute;n se aplicar&aacute;n los cambios realizados en el carro y recalcular todos los precios.</div>'
  },
  'use same shipping as billing' => {
    'lastUpdated' => '1276809777',
    'message' => 'Usar dirección de envío como dirección de cobro.'
  },
  'use this address' => {
    'lastUpdated' => '1215811268',
    'message' => 'Usar Esta Direcci&oacute;n'
  },
  'useButton help' => {
    'lastUpdated' => '1221786515',
    'message' => 'Un bot&oacute;n que permitir&aacute; al usuario seleccionar una direcci&oacute;n existente para usar en el formulario.'
  },
  'userId' => {
    'lastUpdated' => '1215811157',
    'message' => 'El userId del usuario que realiza esta transacci&oacute;n.'
  },
  'userIsVisitor help' => {
    'lastUpdated' => '1280866744',
    'message' => 'Un condicional que indica si el usuario actual es el Invitado.'
  },
  'username' => {
    'lastUpdated' => '1215811068',
    'message' => 'Usuario'
  },
  'username help' => {
    'lastUpdated' => '1221786000',
    'message' => 'El nombre del usuario que realiza esta operaci&oacute;n, para ahorrarle un nombre de usuario buscar.'
  },
  'vendor id' => {
    'lastUpdated' => '1253920312',
    'message' => 'Vendor ID'
  },
  'vendor name' => {
    'lastUpdated' => '1253920318',
    'message' => 'Nombre'
  },
  'vendor payouts' => {
    'lastUpdated' => '1253920326',
    'message' => 'Pagos al Proveedor'
  },
  'vendors' => {
    'lastUpdated' => '1215811050',
    'message' => 'Vendedores'
  },
  'view cart' => {
    'lastUpdated' => '1215811079',
    'message' => 'Ver Carrito'
  },
  'view my purchases template' => {
    'lastUpdated' => '1221673998',
    'message' => 'Plantilla Ver Mis Compras'
  },
  'view my purchases template help' => {
    'lastUpdated' => '1221673971',
    'message' => 'Esta plantilla muestra informaci&oacute;n detallada sobre las transacciones del usuario.'
  },
  'view products' => {
    'lastUpdated' => '1215811672',
    'message' => 'Ver todos los productos importados.'
  },
  'viewDetailURL' => {
    'lastUpdated' => '1221673872',
    'message' => 'Una URL para ver m&aacute;s detalles sobre la transacci&oacute;n del usuario.'
  },
  'viewItemUrl' => {
    'lastUpdated' => '1221673802',
    'message' => 'Una URL para ver los detalles sobre el item de la transacci&oacute;n.'
  },
  'vp item id' => {
    'lastUpdated' => '1253920334',
    'message' => 'Item ID'
  },
  'vp item payout amount' => {
    'lastUpdated' => '1253920342',
    'message' => 'Monto a pagar'
  },
  'vp item payout status' => {
    'lastUpdated' => '1253920349',
    'message' => 'Estado del Pago'
  },
  'vp item price' => {
    'lastUpdated' => '1253920355',
    'message' => 'Precio'
  },
  'vp item quantity' => {
    'lastUpdated' => '1253920362',
    'message' => 'Cantidad'
  },
  'vp item title' => {
    'lastUpdated' => '1253920371',
    'message' => 'Item'
  },
  'vp payouts' => {
    'lastUpdated' => '1259455779',
    'message' => 'Pagos'
  },
  'vp select vendor' => {
    'lastUpdated' => '1259455799',
    'message' => 'Indique el proveedor de la lista cuyos pagos desea gestionar.'
  },
  'vp vendors' => {
    'lastUpdated' => '1259455807',
    'message' => 'Proveedor'
  },
  'weekly' => {
    'lastUpdated' => '1221673766',
    'message' => 'Semana'
  },
  'who can manage' => {
    'lastUpdated' => '1215811037',
    'message' => 'Qui&eacute;n puede administar?'
  },
  'who can manage help' => {
    'lastUpdated' => '1221673780',
    'message' => '<p>El grupo administrador de ecommerce </p>'
  },
  'who is a cashier' => {
    'lastUpdated' => '1233080347',
    'message' => 'Quién es un cajero?'
  },
  'who is a cashier help' => {
    'lastUpdated' => '1233080391',
    'message' => 'Los cajeros son capaces de hacer compras en nombre de otro usuario, escriba la dirección de correo electrónico del usuario en el carro.'
  },
  'yearly' => {
    'lastUpdated' => '1221673770',
    'message' => 'A&ntilde;o'
  }
}
;

1;
